.. pybiopax documentation master file, created by
   sphinx-quickstart on Thu May 28 14:40:01 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyBioPAX documentation
======================

.. toctree::
   :maxdepth: 3

   modules/api
   modules/biopax
   modules/pc_client
   modules/paths
   modules/references
   modules/xml_util


* :ref:`genindex`
* :ref:`modindex`
